# IndieWebify’ing the Site

Thu 21 November 2013 by bear

I’ve been following, heck even participated in the earlier scene, the IndieWeb movement by trying to always use microformats, open standards and the like. The earlier work sometimes was rather tedious in ways that just didn’t make sense.

Cue a couple years of iteration …

Now the IndieWeb is going even stronger, what with the NSA Snowden stuff and people realizing that even friendly and nice looking silos are still just that, silos — looking at you Google! One site that makes it very easy to implement is IndieWebify.Me and it’s series of guides and examples.

Currently I’m at Level 2.1 - h-card and h-entry items are all in place, just need to figure out how to do WebMentions with a purely static site.

test post link